@@ -33,6 +33,11 @@ def incorrect_public_key() -> str:
     return _get_key('incorrect.public.key')
 
 
+@pytest.fixture(scope='session')
+def other_public_key(incorrect_public_key: str) -> str:
+    return incorrect_public_key
+
+
 # This is called key_config and not just config
 # to avoid fixture recursion where future config depends
 # on idp_public_key, but idp_public_key depends on config..
@@ -75,3 +80,16 @@ def run_idp_key_check(idp_public_key: str, idp_private_key: str):
             raise Exception('There is a problem with the IDP keys')
         else:
             warnings.warn('The IDP Keys do not seem to match - this may cause tests to fail')
+
+
+__all__ = [
+    'key_config',
+    'idp_key_check',
+    'idp_private_key',
+    'alt_idp_public_key',
+    'private_key',
+    'public_key',
+    'idp_public_key',
+    'other_public_key',
+    'incorrect_public_key',
+]
